<?xml version="1.0" encoding="UTF-8"?>
<rss xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" version="2.0">
  <channel>
    <title>topic Sorry for the delay in in OpenCL* for CPU</title>
    <link>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030680#M3571</link>
    <description>&lt;P&gt;Sorry for the delay in getting back to you. &amp;nbsp;There are several issues with unions, including support in the kernel builder. &amp;nbsp;We're looking into what can be done. &amp;nbsp;There are many things that need to be prioritized, and your feedback can help. &amp;nbsp;How critical is union support for your application? &amp;nbsp;&lt;/P&gt;</description>
    <pubDate>Wed, 10 Sep 2014 04:23:30 GMT</pubDate>
    <dc:creator>Jeffrey_M_Intel1</dc:creator>
    <dc:date>2014-09-10T04:23:30Z</dc:date>
    <item>
      <title>Debugger doesn't display local variable</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030678#M3569</link>
      <description>&lt;P&gt;I try to debug some opencl kernel in Visual Studio 2013. After entering in kernel debugger show me local variables, but only before row with union operator (#11). Once debug go to row 11 a "Locals" window is cleared. I think this is a bug. (sorry for my english)&lt;/P&gt;

&lt;PRE class="brush:cpp;"&gt;__kernel void randn2(float sigma, unsigned int user_k, __global float4* out)
{
	philox4x32_key_t k = {{get_global_id(0), get_global_id(1)}};
	philox4x32_ctr_t c = {{ 0, 0xf00dcafe, 0xdeadbeef, user_k }};
	float4 buf={0, 0, 0, 0};
	float2 cos2;
	union {
		philox4x32_ctr_t c;
		uint4 ui;
		float4 f;
	} u;
	u.c = philox4x32_R(7,c, k);
	u.f = convert_float4(u.ui) / UINT_MAX;
&lt;/PRE&gt;

&lt;P&gt;&amp;nbsp;&lt;/P&gt;</description>
      <pubDate>Tue, 26 Aug 2014 11:29:30 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030678#M3569</guid>
      <dc:creator>Tar__Alex</dc:creator>
      <dc:date>2014-08-26T11:29:30Z</dc:date>
    </item>
    <item>
      <title>Thanks Alex!  I agree that</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030679#M3570</link>
      <description>&lt;P&gt;Thanks Alex! &amp;nbsp;I agree that this looks like a bug. &amp;nbsp;I've replicated the behavior you've described and reported to the development team. &amp;nbsp;&lt;/P&gt;</description>
      <pubDate>Wed, 03 Sep 2014 07:39:22 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030679#M3570</guid>
      <dc:creator>Jeffrey_M_Intel1</dc:creator>
      <dc:date>2014-09-03T07:39:22Z</dc:date>
    </item>
    <item>
      <title>Sorry for the delay in</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030680#M3571</link>
      <description>&lt;P&gt;Sorry for the delay in getting back to you. &amp;nbsp;There are several issues with unions, including support in the kernel builder. &amp;nbsp;We're looking into what can be done. &amp;nbsp;There are many things that need to be prioritized, and your feedback can help. &amp;nbsp;How critical is union support for your application? &amp;nbsp;&lt;/P&gt;</description>
      <pubDate>Wed, 10 Sep 2014 04:23:30 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030680#M3571</guid>
      <dc:creator>Jeffrey_M_Intel1</dc:creator>
      <dc:date>2014-09-10T04:23:30Z</dc:date>
    </item>
    <item>
      <title>In the future it is will be</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030681#M3572</link>
      <description>&lt;P style="line-height: 19.5120010375977px;"&gt;In the future it is will be critical, but not now. Simply in some cases using union is very &lt;SPAN style="color: rgb(68, 68, 68); font-family: 'Segoe UI'; font-size: 14px; line-height: 20px;"&gt;convenient&lt;/SPAN&gt;.&lt;/P&gt;

&lt;P style="line-height: 19.5120010375977px;"&gt;Now I can use workaround.&lt;/P&gt;</description>
      <pubDate>Wed, 10 Sep 2014 04:36:46 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Debugger-doesn-t-display-local-variable/m-p/1030681#M3572</guid>
      <dc:creator>Tar__Alex</dc:creator>
      <dc:date>2014-09-10T04:36:46Z</dc:date>
    </item>
  </channel>
</rss>

